/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 130 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qlist.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQList1300.cpp"



extern "C" {static void assign_QList_1300(void *, Py_ssize_t, void *);}
static void assign_QList_1300(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QList<unsigned char> *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QList<unsigned char> *>(sipSrc);
}


extern "C" {static void *array_QList_1300(Py_ssize_t);}
static void *array_QList_1300(Py_ssize_t sipNrElem)
{
    return new ::QList<unsigned char>[sipNrElem];
}


extern "C" {static void *copy_QList_1300(const void *, Py_ssize_t);}
static void *copy_QList_1300(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QList<unsigned char>(reinterpret_cast<const ::QList<unsigned char> *>(sipSrc)[sipSrcIdx]);
}


/* Call the mapped type's destructor. */
extern "C" {static void release_QList_1300(void *, int, void *);}
static void release_QList_1300(void *sipCppV, int, void *)
{
    ::QList<unsigned char> *sipCpp = reinterpret_cast< ::QList<unsigned char> *>(sipCppV);
    delete sipCpp;
}



extern "C" {static int convertTo_QList_1300(PyObject *, void **, int *, PyObject *, void **);}
static int convertTo_QList_1300(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj, void **)
{
    ::QList<unsigned char> **sipCppPtr = reinterpret_cast< ::QList<unsigned char> **>(sipCppPtrV);

#line 138 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qcustom3dvolume.sip"
    if (!sipIsErr)
        return sipGetBufferInfo(sipPy, NULL);

    const void *buffer;
    Py_ssize_t buffer_len;

    sipBufferInfoDef bi;

    if (sipGetBufferInfo(sipPy, &bi) < 0)
    {
        *sipIsErr = 1;
        return 0;
    }

    buffer = bi.bi_buf;
    buffer_len = bi.bi_len;

    QList<unsigned char> *qv = new QList<unsigned char>(buffer_len);

    for (Py_ssize_t i = 0; i < buffer_len; ++i)
        (*qv)[i] = reinterpret_cast<const uchar *>(buffer)[i];

    *sipCppPtr = qv;
 
    sipReleaseBufferInfo(&bi);

    return sipGetState(sipTransferObj);
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQList1300.cpp"
}


extern "C" {static PyObject *convertFrom_QList_1300(void *, PyObject *);}
static PyObject *convertFrom_QList_1300(void *sipCppV, PyObject *)
{
    ::QList<unsigned char> *sipCpp = reinterpret_cast< ::QList<unsigned char> *>(sipCppV);

#line 134 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qcustom3dvolume.sip"
    return sipConvertToArray(reinterpret_cast<void *>(sipCpp->data()), "B", sipCpp->size(), 0);
#line 108 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQList1300.cpp"
}


sipMappedTypeDef sipTypeDef_QtDataVisualization_QList_1300 = {
    {
        SIP_NULLPTR,
        SIP_TYPE_MAPPED,
        sipNameNr_4773,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        -1,
        {0, 0, 1},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
    },
    assign_QList_1300,
    array_QList_1300,
    copy_QList_1300,
    release_QList_1300,
    convertTo_QList_1300,
    convertFrom_QList_1300
};
