/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 27 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 88 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 91 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 94 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 103 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataProxy.cpp"


class sipQSurfaceDataProxy : public ::QSurfaceDataProxy
{
public:
    sipQSurfaceDataProxy(::QObject*);
    virtual ~sipQSurfaceDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSurfaceDataProxy(const sipQSurfaceDataProxy &);
    sipQSurfaceDataProxy &operator = (const sipQSurfaceDataProxy &);

    char sipPyMethods[7];
};

sipQSurfaceDataProxy::sipQSurfaceDataProxy(::QObject*a0): ::QSurfaceDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSurfaceDataProxy::~sipQSurfaceDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSurfaceDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QSurfaceDataProxy);

    return ::QSurfaceDataProxy::metaObject();
}

int sipQSurfaceDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSurfaceDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QSurfaceDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSurfaceDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QSurfaceDataProxy, _clname, &sipCpp) ? sipCpp : ::QSurfaceDataProxy::qt_metacast(_clname));
}

void sipQSurfaceDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSurfaceDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurfaceDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSurfaceDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurfaceDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSurfaceDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurfaceDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSurfaceDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurfaceDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSurfaceDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSurfaceDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSurfaceDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSurfaceDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSurfaceDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_rowCount, "rowCount(self) -> int");

extern "C" {static PyObject *meth_QSurfaceDataProxy_rowCount(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_rowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->rowCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_rowCount, doc_QSurfaceDataProxy_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_columnCount, "columnCount(self) -> int");

extern "C" {static PyObject *meth_QSurfaceDataProxy_columnCount(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_columnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columnCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_columnCount, doc_QSurfaceDataProxy_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_array, "array(self) -> list[list[QSurfaceDataItem]]");

extern "C" {static PyObject *meth_QSurfaceDataProxy_array(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_array(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp))
        {
            const ::QSurfaceDataArray*sipRes;

            sipRes = sipCpp->array();

            return sipConvertFromType(const_cast< ::QSurfaceDataArray *>(sipRes), sipType_QList_0601QList_0100QSurfaceDataItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_array, doc_QSurfaceDataProxy_array);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_resetArray, "resetArray(self, newArray: Iterable[Iterable[QSurfaceDataItem]])");

extern "C" {static PyObject *meth_QSurfaceDataProxy_resetArray(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_resetArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSurfaceDataArray* a0;
        int a0State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, sipType_QList_0601QList_0100QSurfaceDataItem, &a0, &a0State))
        {
            sipCpp->resetArray(a0);
            sipReleaseType(a0, sipType_QList_0601QList_0100QSurfaceDataItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_resetArray, doc_QSurfaceDataProxy_resetArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_setRow, "setRow(self, rowIndex: int, row: Iterable[QSurfaceDataItem])");

extern "C" {static PyObject *meth_QSurfaceDataProxy_setRow(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_setRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSurfaceDataRow* a1;
        int a1State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, sipType_QList_0100QSurfaceDataItem, &a1, &a1State))
        {
            sipCpp->setRow(a0, a1);
            sipReleaseType(a1, sipType_QList_0100QSurfaceDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_setRow, doc_QSurfaceDataProxy_setRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_setRows, "setRows(self, rowIndex: int, rows: Iterable[Iterable[QSurfaceDataItem]])");

extern "C" {static PyObject *meth_QSurfaceDataProxy_setRows(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_setRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QSurfaceDataArray* a1;
        int a1State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, sipType_QList_0601QList_0100QSurfaceDataItem, &a1, &a1State))
        {
            sipCpp->setRows(a0, *a1);
            sipReleaseType(const_cast< ::QSurfaceDataArray *>(a1), sipType_QList_0601QList_0100QSurfaceDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_setRows, doc_QSurfaceDataProxy_setRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_setItem, "setItem(self, rowIndex: int, columnIndex: int, item: QSurfaceDataItem)\n"
"setItem(self, position: QPoint, item: QSurfaceDataItem)");

extern "C" {static PyObject *meth_QSurfaceDataProxy_setItem(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_setItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QSurfaceDataItem* a2;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, &a1, sipType_QSurfaceDataItem, &a2))
        {
            sipCpp->setItem(a0, a1, *a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPoint* a0;
        const ::QSurfaceDataItem* a1;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, sipType_QPoint, &a0, sipType_QSurfaceDataItem, &a1))
        {
            sipCpp->setItem(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_setItem, doc_QSurfaceDataProxy_setItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_addRow, "addRow(self, row: Iterable[QSurfaceDataItem]) -> int");

extern "C" {static PyObject *meth_QSurfaceDataProxy_addRow(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_addRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSurfaceDataRow* a0;
        int a0State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, sipType_QList_0100QSurfaceDataItem, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->addRow(a0);
            sipReleaseType(a0, sipType_QList_0100QSurfaceDataItem, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_addRow, doc_QSurfaceDataProxy_addRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_addRows, "addRows(self, rows: Iterable[Iterable[QSurfaceDataItem]]) -> int");

extern "C" {static PyObject *meth_QSurfaceDataProxy_addRows(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_addRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataArray* a0;
        int a0State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, sipType_QList_0601QList_0100QSurfaceDataItem, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->addRows(*a0);
            sipReleaseType(const_cast< ::QSurfaceDataArray *>(a0), sipType_QList_0601QList_0100QSurfaceDataItem, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_addRows, doc_QSurfaceDataProxy_addRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_insertRow, "insertRow(self, rowIndex: int, row: Iterable[QSurfaceDataItem])");

extern "C" {static PyObject *meth_QSurfaceDataProxy_insertRow(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_insertRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QSurfaceDataRow* a1;
        int a1State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, sipType_QList_0100QSurfaceDataItem, &a1, &a1State))
        {
            sipCpp->insertRow(a0, a1);
            sipReleaseType(a1, sipType_QList_0100QSurfaceDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_insertRow, doc_QSurfaceDataProxy_insertRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_insertRows, "insertRows(self, rowIndex: int, rows: Iterable[Iterable[QSurfaceDataItem]])");

extern "C" {static PyObject *meth_QSurfaceDataProxy_insertRows(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_insertRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QSurfaceDataArray* a1;
        int a1State = 0;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, sipType_QList_0601QList_0100QSurfaceDataItem, &a1, &a1State))
        {
            sipCpp->insertRows(a0, *a1);
            sipReleaseType(const_cast< ::QSurfaceDataArray *>(a1), sipType_QList_0601QList_0100QSurfaceDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_insertRows, doc_QSurfaceDataProxy_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_removeRows, "removeRows(self, rowIndex: int, removeCount: int)");

extern "C" {static PyObject *meth_QSurfaceDataProxy_removeRows(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_removeRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, &a1))
        {
            sipCpp->removeRows(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_removeRows, doc_QSurfaceDataProxy_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_series, "series(self) -> QSurface3DSeries|None");

extern "C" {static PyObject *meth_QSurfaceDataProxy_series(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp))
        {
            ::QSurface3DSeries*sipRes;

            sipRes = sipCpp->series();

            return sipConvertFromType(sipRes, sipType_QSurface3DSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_series, doc_QSurfaceDataProxy_series);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataProxy_itemAt, "itemAt(self, rowIndex: int, columnIndex: int) -> QSurfaceDataItem|None\n"
"itemAt(self, position: QPoint) -> QSurfaceDataItem|None");

extern "C" {static PyObject *meth_QSurfaceDataProxy_itemAt(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataProxy_itemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, &a0, &a1))
        {
            const ::QSurfaceDataItem*sipRes;

            sipRes = sipCpp->itemAt(a0, a1);

            return sipConvertFromType(const_cast< ::QSurfaceDataItem *>(sipRes), sipType_QSurfaceDataItem, SIP_NULLPTR);
        }
    }

    {
        const ::QPoint* a0;
        const ::QSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSurfaceDataProxy, &sipCpp, sipType_QPoint, &a0))
        {
            const ::QSurfaceDataItem*sipRes;

            sipRes = sipCpp->itemAt(*a0);

            return sipConvertFromType(const_cast< ::QSurfaceDataItem *>(sipRes), sipType_QSurfaceDataItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataProxy, sipName_itemAt, doc_QSurfaceDataProxy_itemAt);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSurfaceDataProxy(void *, const sipTypeDef *);}
static void *cast_QSurfaceDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSurfaceDataProxy *sipCpp = reinterpret_cast< ::QSurfaceDataProxy *>(sipCppV);

    if (targetType == sipType_QSurfaceDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstractDataProxy)->ctd_cast(static_cast< ::QAbstractDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSurfaceDataProxy(void *, int);}
static void release_QSurfaceDataProxy(void *sipCppV, int)
{
    ::QSurfaceDataProxy *sipCpp = reinterpret_cast< ::QSurfaceDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSurfaceDataProxy(Py_ssize_t);}
static void *array_QSurfaceDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QSurfaceDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QSurfaceDataProxy(void *);}
static void array_delete_QSurfaceDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSurfaceDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QSurfaceDataProxy(sipSimpleWrapper *);}
static void dealloc_QSurfaceDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSurfaceDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSurfaceDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSurfaceDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSurfaceDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSurfaceDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSurfaceDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSurfaceDataProxy[] = {{25, 255, 1}};


static PyMethodDef methods_QSurfaceDataProxy[] = {
    {sipName_addRow, meth_QSurfaceDataProxy_addRow, METH_VARARGS, doc_QSurfaceDataProxy_addRow},
    {sipName_addRows, meth_QSurfaceDataProxy_addRows, METH_VARARGS, doc_QSurfaceDataProxy_addRows},
    {sipName_array, meth_QSurfaceDataProxy_array, METH_VARARGS, doc_QSurfaceDataProxy_array},
    {sipName_columnCount, meth_QSurfaceDataProxy_columnCount, METH_VARARGS, doc_QSurfaceDataProxy_columnCount},
    {sipName_insertRow, meth_QSurfaceDataProxy_insertRow, METH_VARARGS, doc_QSurfaceDataProxy_insertRow},
    {sipName_insertRows, meth_QSurfaceDataProxy_insertRows, METH_VARARGS, doc_QSurfaceDataProxy_insertRows},
    {sipName_itemAt, meth_QSurfaceDataProxy_itemAt, METH_VARARGS, doc_QSurfaceDataProxy_itemAt},
    {sipName_removeRows, meth_QSurfaceDataProxy_removeRows, METH_VARARGS, doc_QSurfaceDataProxy_removeRows},
    {sipName_resetArray, meth_QSurfaceDataProxy_resetArray, METH_VARARGS, doc_QSurfaceDataProxy_resetArray},
    {sipName_rowCount, meth_QSurfaceDataProxy_rowCount, METH_VARARGS, doc_QSurfaceDataProxy_rowCount},
    {sipName_series, meth_QSurfaceDataProxy_series, METH_VARARGS, doc_QSurfaceDataProxy_series},
    {sipName_setItem, meth_QSurfaceDataProxy_setItem, METH_VARARGS, doc_QSurfaceDataProxy_setItem},
    {sipName_setRow, meth_QSurfaceDataProxy_setRow, METH_VARARGS, doc_QSurfaceDataProxy_setRow},
    {sipName_setRows, meth_QSurfaceDataProxy_setRows, METH_VARARGS, doc_QSurfaceDataProxy_setRows}
};

PyDoc_STRVAR(doc_QSurfaceDataProxy, "\1QSurfaceDataProxy(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSurfaceDataProxy[] = {
    {"seriesChanged(QSurface3DSeries*)", "\1seriesChanged(self, series: QSurface3DSeries|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnCountChanged(int)", "\1columnCountChanged(self, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowCountChanged(int)", "\1rowCountChanged(self, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemChanged(int,int)", "\1itemChanged(self, rowIndex: int, columnIndex: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsInserted(int,int)", "\1rowsInserted(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsRemoved(int,int)", "\1rowsRemoved(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsChanged(int,int)", "\1rowsChanged(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsAdded(int,int)", "\1rowsAdded(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"arrayReset()", "\1arrayReset(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSurfaceDataProxy = {
    &::QSurfaceDataProxy::staticMetaObject,
    signals_QSurfaceDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QSurfaceDataProxy = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSurfaceDataProxy,
        SIP_NULLPTR,
        &plugin_QSurfaceDataProxy,
    },
    {
        sipNameNr_QSurfaceDataProxy,
        {0, 0, 1},
        14, methods_QSurfaceDataProxy,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSurfaceDataProxy,
    -1,
    -1,
    supers_QSurfaceDataProxy,
    SIP_NULLPTR,
    init_type_QSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSurfaceDataProxy,
    SIP_NULLPTR,
    array_QSurfaceDataProxy,
    SIP_NULLPTR,
    release_QSurfaceDataProxy,
    cast_QSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSurfaceDataProxy,
    sizeof (::QSurfaceDataProxy),
};
