/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"

#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qwindow.sip"
#include <qwindow.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 114 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 54 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 57 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 60 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 81 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 63 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 66 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 69 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 72 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 75 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 78 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 33 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 81 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 84 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 788 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 87 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 754 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 90 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 848 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 93 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 619 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 96 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 283 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 99 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 102 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 105 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 108 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 111 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 114 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 117 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 120 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 123 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 128 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 131 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 134 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 116 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 137 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 297 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 140 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 143 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 146 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 149 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 145 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qglobal.sip"
#include <QtGlobal>
#line 152 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 155 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 807 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 158 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 213 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 161 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 339 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 164 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 325 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 167 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 239 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 269 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 176 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 179 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qscreen.sip"
#include <qscreen.h>
#line 182 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 185 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 188 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 110 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 191 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qicon.sip"
#include <qicon.h>
#line 194 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 197 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qsurface.sip"
#include <qsurface.h>
#line 200 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 205 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 208 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 211 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 214 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 217 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 220 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 223 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 226 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 229 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 232 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 235 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 238 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQ3DBars.cpp"


class sipQ3DBars : public ::Q3DBars
{
public:
    sipQ3DBars(const ::QSurfaceFormat*, ::QWindow*);
    virtual ~sipQ3DBars();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void exposeEvent(::QExposeEvent*) SIP_OVERRIDE;
    ::QObject* focusObject() const SIP_OVERRIDE;
    ::QSurfaceFormat format() const SIP_OVERRIDE;
    ::QSurface::SurfaceType surfaceType() const SIP_OVERRIDE;
    ::QSize size() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    bool shadowsSupported() const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQ3DBars(const sipQ3DBars &);
    sipQ3DBars &operator = (const sipQ3DBars &);

    char sipPyMethods[31];
};

sipQ3DBars::sipQ3DBars(const ::QSurfaceFormat*a0, ::QWindow*a1): ::Q3DBars(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQ3DBars::~sipQ3DBars()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQ3DBars::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_Q3DBars);

    return ::Q3DBars::metaObject();
}

int sipQ3DBars::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::Q3DBars::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_Q3DBars, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQ3DBars::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_Q3DBars, _clname, &sipCpp) ? sipCpp : ::Q3DBars::qt_metacast(_clname));
}

bool sipQ3DBars::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::Q3DBars::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtDataVisualization_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtDataVisualization_0(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQ3DBars::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::Q3DBars::closeEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtDataVisualization_1(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::Q3DBars::paintEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtDataVisualization_2(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::Q3DBars::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtDataVisualization_3(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::touchEvent(::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_touchEvent);

    if (!sipMeth)
    {
        ::Q3DBars::touchEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTouchEvent*);

    sipVH_QtDataVisualization_4(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::Q3DBars::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtDataVisualization_5(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::Q3DBars::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_6(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::Q3DBars::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_6(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::Q3DBars::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_6(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::Q3DBars::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_6(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::Q3DBars::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtDataVisualization_7(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::Q3DBars::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtDataVisualization_7(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::Q3DBars::hideEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtDataVisualization_8(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::Q3DBars::showEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtDataVisualization_9(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::Q3DBars::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtDataVisualization_10(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::Q3DBars::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtDataVisualization_10(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::Q3DBars::moveEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtDataVisualization_11(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::Q3DBars::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtDataVisualization_12(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::exposeEvent(::QExposeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_exposeEvent);

    if (!sipMeth)
    {
        ::Q3DBars::exposeEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QExposeEvent*);

    sipVH_QtDataVisualization_13(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QObject* sipQ3DBars::focusObject() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_focusObject);

    if (!sipMeth)
        return ::Q3DBars::focusObject();

    extern ::QObject* sipVH_QtDataVisualization_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_14(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurfaceFormat sipQ3DBars::format() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[20]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_format);

    if (!sipMeth)
        return ::Q3DBars::format();

    extern ::QSurfaceFormat sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSurface::SurfaceType sipQ3DBars::surfaceType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[21]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_surfaceType);

    if (!sipMeth)
        return ::Q3DBars::surfaceType();

    extern ::QSurface::SurfaceType sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQ3DBars::size() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[22]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_size);

    if (!sipMeth)
        return ::Q3DBars::size();

    extern ::QSize sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQ3DBars::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::Q3DBars::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQ3DBars::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::Q3DBars::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQ3DBars::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::Q3DBars::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::Q3DBars::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::Q3DBars::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::Q3DBars::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQ3DBars::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::Q3DBars::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQ3DBars::shadowsSupported() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[30]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_shadowsSupported);

    if (!sipMeth)
        return ::Q3DBars::shadowsSupported();

    extern bool sipVH_QtDataVisualization_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_24(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}


PyDoc_STRVAR(doc_Q3DBars_setPrimarySeries, "setPrimarySeries(self, series: QBar3DSeries|None)");

extern "C" {static PyObject *meth_Q3DBars_setPrimarySeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setPrimarySeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBar3DSeries* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QBar3DSeries, &a0))
        {
            sipCpp->setPrimarySeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setPrimarySeries, doc_Q3DBars_setPrimarySeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_primarySeries, "primarySeries(self) -> QBar3DSeries|None");

extern "C" {static PyObject *meth_Q3DBars_primarySeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_primarySeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QBar3DSeries*sipRes;

            sipRes = sipCpp->primarySeries();

            return sipConvertFromType(sipRes, sipType_QBar3DSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_primarySeries, doc_Q3DBars_primarySeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_addSeries, "addSeries(self, series: QBar3DSeries|None)");

extern "C" {static PyObject *meth_Q3DBars_addSeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_addSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBar3DSeries* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QBar3DSeries, &a0))
        {
            sipCpp->addSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_addSeries, doc_Q3DBars_addSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_removeSeries, "removeSeries(self, series: QBar3DSeries|None)");

extern "C" {static PyObject *meth_Q3DBars_removeSeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_removeSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QBar3DSeries* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QBar3DSeries, &a0))
        {
            sipCpp->removeSeries(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_removeSeries, doc_Q3DBars_removeSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_insertSeries, "insertSeries(self, index: int, series: QBar3DSeries|None)");

extern "C" {static PyObject *meth_Q3DBars_insertSeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_insertSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QBar3DSeries* a1;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_Q3DBars, &sipCpp, &a0, sipType_QBar3DSeries, &a1))
        {
            sipCpp->insertSeries(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_insertSeries, doc_Q3DBars_insertSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_seriesList, "seriesList(self) -> list[QBar3DSeries]");

extern "C" {static PyObject *meth_Q3DBars_seriesList(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_seriesList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            QList< ::QBar3DSeries*>*sipRes;

            sipRes = new QList< ::QBar3DSeries*>(sipCpp->seriesList());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QBar3DSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_seriesList, doc_Q3DBars_seriesList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setMultiSeriesUniform, "setMultiSeriesUniform(self, uniform: bool)");

extern "C" {static PyObject *meth_Q3DBars_setMultiSeriesUniform(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setMultiSeriesUniform(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Q3DBars, &sipCpp, &a0))
        {
            sipCpp->setMultiSeriesUniform(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setMultiSeriesUniform, doc_Q3DBars_setMultiSeriesUniform);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_isMultiSeriesUniform, "isMultiSeriesUniform(self) -> bool");

extern "C" {static PyObject *meth_Q3DBars_isMultiSeriesUniform(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_isMultiSeriesUniform(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMultiSeriesUniform();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_isMultiSeriesUniform, doc_Q3DBars_isMultiSeriesUniform);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setBarThickness, "setBarThickness(self, thicknessRatio: float)");

extern "C" {static PyObject *meth_Q3DBars_setBarThickness(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setBarThickness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Q3DBars, &sipCpp, &a0))
        {
            sipCpp->setBarThickness(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setBarThickness, doc_Q3DBars_setBarThickness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_barThickness, "barThickness(self) -> float");

extern "C" {static PyObject *meth_Q3DBars_barThickness(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_barThickness(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->barThickness();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_barThickness, doc_Q3DBars_barThickness);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setBarSpacing, "setBarSpacing(self, spacing: QSizeF)");

extern "C" {static PyObject *meth_Q3DBars_setBarSpacing(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setBarSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSizeF* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QSizeF, &a0))
        {
            sipCpp->setBarSpacing(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setBarSpacing, doc_Q3DBars_setBarSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_barSpacing, "barSpacing(self) -> QSizeF");

extern "C" {static PyObject *meth_Q3DBars_barSpacing(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_barSpacing(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->barSpacing());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_barSpacing, doc_Q3DBars_barSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setBarSpacingRelative, "setBarSpacingRelative(self, relative: bool)");

extern "C" {static PyObject *meth_Q3DBars_setBarSpacingRelative(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setBarSpacingRelative(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Q3DBars, &sipCpp, &a0))
        {
            sipCpp->setBarSpacingRelative(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setBarSpacingRelative, doc_Q3DBars_setBarSpacingRelative);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_isBarSpacingRelative, "isBarSpacingRelative(self) -> bool");

extern "C" {static PyObject *meth_Q3DBars_isBarSpacingRelative(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_isBarSpacingRelative(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBarSpacingRelative();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_isBarSpacingRelative, doc_Q3DBars_isBarSpacingRelative);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setRowAxis, "setRowAxis(self, axis: QCategory3DAxis|None)");

extern "C" {static PyObject *meth_Q3DBars_setRowAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setRowAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCategory3DAxis* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QCategory3DAxis, &a0))
        {
            sipCpp->setRowAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setRowAxis, doc_Q3DBars_setRowAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_rowAxis, "rowAxis(self) -> QCategory3DAxis|None");

extern "C" {static PyObject *meth_Q3DBars_rowAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_rowAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QCategory3DAxis*sipRes;

            sipRes = sipCpp->rowAxis();

            return sipConvertFromType(sipRes, sipType_QCategory3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_rowAxis, doc_Q3DBars_rowAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setColumnAxis, "setColumnAxis(self, axis: QCategory3DAxis|None)");

extern "C" {static PyObject *meth_Q3DBars_setColumnAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setColumnAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QCategory3DAxis* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QCategory3DAxis, &a0))
        {
            sipCpp->setColumnAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setColumnAxis, doc_Q3DBars_setColumnAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_columnAxis, "columnAxis(self) -> QCategory3DAxis|None");

extern "C" {static PyObject *meth_Q3DBars_columnAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_columnAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QCategory3DAxis*sipRes;

            sipRes = sipCpp->columnAxis();

            return sipConvertFromType(sipRes, sipType_QCategory3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_columnAxis, doc_Q3DBars_columnAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setValueAxis, "setValueAxis(self, axis: QValue3DAxis|None)");

extern "C" {static PyObject *meth_Q3DBars_setValueAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setValueAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QValue3DAxis* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QValue3DAxis, &a0))
        {
            sipCpp->setValueAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setValueAxis, doc_Q3DBars_setValueAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_valueAxis, "valueAxis(self) -> QValue3DAxis|None");

extern "C" {static PyObject *meth_Q3DBars_valueAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_valueAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QValue3DAxis*sipRes;

            sipRes = sipCpp->valueAxis();

            return sipConvertFromType(sipRes, sipType_QValue3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_valueAxis, doc_Q3DBars_valueAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_addAxis, "addAxis(self, axis: QAbstract3DAxis|None)");

extern "C" {static PyObject *meth_Q3DBars_addAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_addAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstract3DAxis* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QAbstract3DAxis, &a0))
        {
            sipCpp->addAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_addAxis, doc_Q3DBars_addAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_releaseAxis, "releaseAxis(self, axis: QAbstract3DAxis|None)");

extern "C" {static PyObject *meth_Q3DBars_releaseAxis(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_releaseAxis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstract3DAxis* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ<", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QAbstract3DAxis, &a0))
        {
            sipCpp->releaseAxis(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_releaseAxis, doc_Q3DBars_releaseAxis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_axes, "axes(self) -> list[QAbstract3DAxis]");

extern "C" {static PyObject *meth_Q3DBars_axes(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_axes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            QList< ::QAbstract3DAxis*>*sipRes;

            sipRes = new QList< ::QAbstract3DAxis*>(sipCpp->axes());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QAbstract3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_axes, doc_Q3DBars_axes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_selectedSeries, "selectedSeries(self) -> QBar3DSeries|None");

extern "C" {static PyObject *meth_Q3DBars_selectedSeries(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_selectedSeries(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QBar3DSeries*sipRes;

            sipRes = sipCpp->selectedSeries();

            return sipConvertFromType(sipRes, sipType_QBar3DSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_selectedSeries, doc_Q3DBars_selectedSeries);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setFloorLevel, "setFloorLevel(self, level: float)");

extern "C" {static PyObject *meth_Q3DBars_setFloorLevel(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setFloorLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_Q3DBars, &sipCpp, &a0))
        {
            sipCpp->setFloorLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setFloorLevel, doc_Q3DBars_setFloorLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_floorLevel, "floorLevel(self) -> float");

extern "C" {static PyObject *meth_Q3DBars_floorLevel(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_floorLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->floorLevel();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_floorLevel, doc_Q3DBars_floorLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_setBarSeriesMargin, "setBarSeriesMargin(self, margin: QSizeF)");

extern "C" {static PyObject *meth_Q3DBars_setBarSeriesMargin(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_setBarSeriesMargin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSizeF* a0;
        ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_Q3DBars, &sipCpp, sipType_QSizeF, &a0))
        {
            sipCpp->setBarSeriesMargin(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_setBarSeriesMargin, doc_Q3DBars_setBarSeriesMargin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Q3DBars_barSeriesMargin, "barSeriesMargin(self) -> QSizeF");

extern "C" {static PyObject *meth_Q3DBars_barSeriesMargin(PyObject *, PyObject *);}
static PyObject *meth_Q3DBars_barSeriesMargin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Q3DBars *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Q3DBars, &sipCpp))
        {
            ::QSizeF*sipRes;

            sipRes = new ::QSizeF(sipCpp->barSeriesMargin());

            return sipConvertFromNewType(sipRes, sipType_QSizeF, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DBars, sipName_barSeriesMargin, doc_Q3DBars_barSeriesMargin);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_Q3DBars(void *, const sipTypeDef *);}
static void *cast_Q3DBars(void *sipCppV, const sipTypeDef *targetType)
{
    ::Q3DBars *sipCpp = reinterpret_cast< ::Q3DBars *>(sipCppV);

    if (targetType == sipType_Q3DBars)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstract3DGraph)->ctd_cast(static_cast< ::QAbstract3DGraph *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Q3DBars(void *, int);}
static void release_Q3DBars(void *sipCppV, int)
{
    ::Q3DBars *sipCpp = reinterpret_cast< ::Q3DBars *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_Q3DBars(Py_ssize_t);}
static void *array_Q3DBars(Py_ssize_t sipNrElem)
{
    return new ::Q3DBars[sipNrElem];
}


extern "C" {static void array_delete_Q3DBars(void *);}
static void array_delete_Q3DBars(void *sipCpp)
{
    delete[] reinterpret_cast< ::Q3DBars *>(sipCpp);
}


extern "C" {static void dealloc_Q3DBars(sipSimpleWrapper *);}
static void dealloc_Q3DBars(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQ3DBars *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Q3DBars(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Q3DBars(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Q3DBars(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQ3DBars *sipCpp = SIP_NULLPTR;

    {
        const ::QSurfaceFormat* a0 = 0;
        ::QWindow* a1 = 0;

        static const char *sipKwdList[] = {
            sipName_format,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|J8JH", sipType_QSurfaceFormat, &a0, sipType_QWindow, &a1, sipOwner))
        {
            sipCpp = new sipQ3DBars(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_Q3DBars[] = {{15, 255, 1}};


static PyMethodDef methods_Q3DBars[] = {
    {sipName_addAxis, meth_Q3DBars_addAxis, METH_VARARGS, doc_Q3DBars_addAxis},
    {sipName_addSeries, meth_Q3DBars_addSeries, METH_VARARGS, doc_Q3DBars_addSeries},
    {sipName_axes, meth_Q3DBars_axes, METH_VARARGS, doc_Q3DBars_axes},
    {sipName_barSeriesMargin, meth_Q3DBars_barSeriesMargin, METH_VARARGS, doc_Q3DBars_barSeriesMargin},
    {sipName_barSpacing, meth_Q3DBars_barSpacing, METH_VARARGS, doc_Q3DBars_barSpacing},
    {sipName_barThickness, meth_Q3DBars_barThickness, METH_VARARGS, doc_Q3DBars_barThickness},
    {sipName_columnAxis, meth_Q3DBars_columnAxis, METH_VARARGS, doc_Q3DBars_columnAxis},
    {sipName_floorLevel, meth_Q3DBars_floorLevel, METH_VARARGS, doc_Q3DBars_floorLevel},
    {sipName_insertSeries, meth_Q3DBars_insertSeries, METH_VARARGS, doc_Q3DBars_insertSeries},
    {sipName_isBarSpacingRelative, meth_Q3DBars_isBarSpacingRelative, METH_VARARGS, doc_Q3DBars_isBarSpacingRelative},
    {sipName_isMultiSeriesUniform, meth_Q3DBars_isMultiSeriesUniform, METH_VARARGS, doc_Q3DBars_isMultiSeriesUniform},
    {sipName_primarySeries, meth_Q3DBars_primarySeries, METH_VARARGS, doc_Q3DBars_primarySeries},
    {sipName_releaseAxis, meth_Q3DBars_releaseAxis, METH_VARARGS, doc_Q3DBars_releaseAxis},
    {sipName_removeSeries, meth_Q3DBars_removeSeries, METH_VARARGS, doc_Q3DBars_removeSeries},
    {sipName_rowAxis, meth_Q3DBars_rowAxis, METH_VARARGS, doc_Q3DBars_rowAxis},
    {sipName_selectedSeries, meth_Q3DBars_selectedSeries, METH_VARARGS, doc_Q3DBars_selectedSeries},
    {sipName_seriesList, meth_Q3DBars_seriesList, METH_VARARGS, doc_Q3DBars_seriesList},
    {sipName_setBarSeriesMargin, meth_Q3DBars_setBarSeriesMargin, METH_VARARGS, doc_Q3DBars_setBarSeriesMargin},
    {sipName_setBarSpacing, meth_Q3DBars_setBarSpacing, METH_VARARGS, doc_Q3DBars_setBarSpacing},
    {sipName_setBarSpacingRelative, meth_Q3DBars_setBarSpacingRelative, METH_VARARGS, doc_Q3DBars_setBarSpacingRelative},
    {sipName_setBarThickness, meth_Q3DBars_setBarThickness, METH_VARARGS, doc_Q3DBars_setBarThickness},
    {sipName_setColumnAxis, meth_Q3DBars_setColumnAxis, METH_VARARGS, doc_Q3DBars_setColumnAxis},
    {sipName_setFloorLevel, meth_Q3DBars_setFloorLevel, METH_VARARGS, doc_Q3DBars_setFloorLevel},
    {sipName_setMultiSeriesUniform, meth_Q3DBars_setMultiSeriesUniform, METH_VARARGS, doc_Q3DBars_setMultiSeriesUniform},
    {sipName_setPrimarySeries, meth_Q3DBars_setPrimarySeries, METH_VARARGS, doc_Q3DBars_setPrimarySeries},
    {sipName_setRowAxis, meth_Q3DBars_setRowAxis, METH_VARARGS, doc_Q3DBars_setRowAxis},
    {sipName_setValueAxis, meth_Q3DBars_setValueAxis, METH_VARARGS, doc_Q3DBars_setValueAxis},
    {sipName_valueAxis, meth_Q3DBars_valueAxis, METH_VARARGS, doc_Q3DBars_valueAxis}
};

PyDoc_STRVAR(doc_Q3DBars, "\1Q3DBars(format: QSurfaceFormat|None = None, parent: QWindow|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_Q3DBars[] = {
    {"barSeriesMarginChanged(QSizeF)", "\1barSeriesMarginChanged(self, margin: QSizeF)", SIP_NULLPTR, SIP_NULLPTR},
    {"floorLevelChanged(float)", "\1floorLevelChanged(self, level: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectedSeriesChanged(QBar3DSeries*)", "\1selectedSeriesChanged(self, series: QBar3DSeries|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"primarySeriesChanged(QBar3DSeries*)", "\1primarySeriesChanged(self, series: QBar3DSeries|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"valueAxisChanged(QValue3DAxis*)", "\1valueAxisChanged(self, axis: QValue3DAxis|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnAxisChanged(QCategory3DAxis*)", "\1columnAxisChanged(self, axis: QCategory3DAxis|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowAxisChanged(QCategory3DAxis*)", "\1rowAxisChanged(self, axis: QCategory3DAxis|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"barSpacingRelativeChanged(bool)", "\1barSpacingRelativeChanged(self, relative: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"barSpacingChanged(QSizeF)", "\1barSpacingChanged(self, spacing: QSizeF)", SIP_NULLPTR, SIP_NULLPTR},
    {"barThicknessChanged(float)", "\1barThicknessChanged(self, thicknessRatio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"multiSeriesUniformChanged(bool)", "\1multiSeriesUniformChanged(self, uniform: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_Q3DBars = {
    &::Q3DBars::staticMetaObject,
    signals_Q3DBars,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_Q3DBars = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Q3DBars,
        SIP_NULLPTR,
        &plugin_Q3DBars,
    },
    {
        sipNameNr_Q3DBars,
        {0, 0, 1},
        28, methods_Q3DBars,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Q3DBars,
    -1,
    -1,
    supers_Q3DBars,
    SIP_NULLPTR,
    init_type_Q3DBars,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Q3DBars,
    SIP_NULLPTR,
    array_Q3DBars,
    SIP_NULLPTR,
    release_Q3DBars,
    cast_Q3DBars,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Q3DBars,
    sizeof (::Q3DBars),
};
