/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 33 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 27 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qlist.sip"
#include <qlist.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 54 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 57 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 62 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 65 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 83 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 91 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQHeightMapSurfaceDataProxy.cpp"


class sipQHeightMapSurfaceDataProxy : public ::QHeightMapSurfaceDataProxy
{
public:
    sipQHeightMapSurfaceDataProxy(::QObject*);
    sipQHeightMapSurfaceDataProxy(const ::QImage&, ::QObject*);
    sipQHeightMapSurfaceDataProxy(const ::QString&, ::QObject*);
    virtual ~sipQHeightMapSurfaceDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQHeightMapSurfaceDataProxy(const sipQHeightMapSurfaceDataProxy &);
    sipQHeightMapSurfaceDataProxy &operator = (const sipQHeightMapSurfaceDataProxy &);

    char sipPyMethods[7];
};

sipQHeightMapSurfaceDataProxy::sipQHeightMapSurfaceDataProxy(::QObject*a0): ::QHeightMapSurfaceDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHeightMapSurfaceDataProxy::sipQHeightMapSurfaceDataProxy(const ::QImage& a0, ::QObject*a1): ::QHeightMapSurfaceDataProxy(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHeightMapSurfaceDataProxy::sipQHeightMapSurfaceDataProxy(const ::QString& a0, ::QObject*a1): ::QHeightMapSurfaceDataProxy(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQHeightMapSurfaceDataProxy::~sipQHeightMapSurfaceDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQHeightMapSurfaceDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QHeightMapSurfaceDataProxy);

    return ::QHeightMapSurfaceDataProxy::metaObject();
}

int sipQHeightMapSurfaceDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QHeightMapSurfaceDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QHeightMapSurfaceDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQHeightMapSurfaceDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QHeightMapSurfaceDataProxy, _clname, &sipCpp) ? sipCpp : ::QHeightMapSurfaceDataProxy::qt_metacast(_clname));
}

bool sipQHeightMapSurfaceDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QHeightMapSurfaceDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQHeightMapSurfaceDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QHeightMapSurfaceDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQHeightMapSurfaceDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QHeightMapSurfaceDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHeightMapSurfaceDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QHeightMapSurfaceDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHeightMapSurfaceDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QHeightMapSurfaceDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHeightMapSurfaceDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QHeightMapSurfaceDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQHeightMapSurfaceDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QHeightMapSurfaceDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setHeightMap, "setHeightMap(self, image: QImage)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setHeightMap(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setHeightMap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, sipType_QImage, &a0))
        {
            sipCpp->setHeightMap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setHeightMap, doc_QHeightMapSurfaceDataProxy_setHeightMap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_heightMap, "heightMap(self) -> QImage");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_heightMap(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_heightMap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->heightMap());

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_heightMap, doc_QHeightMapSurfaceDataProxy_heightMap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setHeightMapFile, "setHeightMapFile(self, filename: str|None)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setHeightMapFile(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setHeightMapFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setHeightMapFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setHeightMapFile, doc_QHeightMapSurfaceDataProxy_setHeightMapFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_heightMapFile, "heightMapFile(self) -> str");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_heightMapFile(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_heightMapFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->heightMapFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_heightMapFile, doc_QHeightMapSurfaceDataProxy_heightMapFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setValueRanges, "setValueRanges(self, minX: float, maxX: float, minZ: float, maxZ: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setValueRanges(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setValueRanges(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        float a2;
        float a3;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bffff", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->setValueRanges(a0, a1, a2, a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setValueRanges, doc_QHeightMapSurfaceDataProxy_setValueRanges);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMinXValue, "setMinXValue(self, min: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMinXValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMinXValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMinXValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMinXValue, doc_QHeightMapSurfaceDataProxy_setMinXValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_minXValue, "minXValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_minXValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_minXValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minXValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_minXValue, doc_QHeightMapSurfaceDataProxy_minXValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMaxXValue, "setMaxXValue(self, max: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxXValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxXValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMaxXValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMaxXValue, doc_QHeightMapSurfaceDataProxy_setMaxXValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_maxXValue, "maxXValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_maxXValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_maxXValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maxXValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_maxXValue, doc_QHeightMapSurfaceDataProxy_maxXValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMinZValue, "setMinZValue(self, min: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMinZValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMinZValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMinZValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMinZValue, doc_QHeightMapSurfaceDataProxy_setMinZValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_minZValue, "minZValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_minZValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_minZValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minZValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_minZValue, doc_QHeightMapSurfaceDataProxy_minZValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMaxZValue, "setMaxZValue(self, max: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxZValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxZValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMaxZValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMaxZValue, doc_QHeightMapSurfaceDataProxy_setMaxZValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_maxZValue, "maxZValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_maxZValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_maxZValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maxZValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_maxZValue, doc_QHeightMapSurfaceDataProxy_maxZValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMinYValue, "setMinYValue(self, min: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMinYValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMinYValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMinYValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMinYValue, doc_QHeightMapSurfaceDataProxy_setMinYValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_minYValue, "minYValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_minYValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_minYValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minYValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_minYValue, doc_QHeightMapSurfaceDataProxy_minYValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setMaxYValue, "setMaxYValue(self, max: float)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxYValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setMaxYValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setMaxYValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setMaxYValue, doc_QHeightMapSurfaceDataProxy_setMaxYValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_maxYValue, "maxYValue(self) -> float");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_maxYValue(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_maxYValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maxYValue();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_maxYValue, doc_QHeightMapSurfaceDataProxy_maxYValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_setAutoScaleY, "setAutoScaleY(self, enabled: bool)");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_setAutoScaleY(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_setAutoScaleY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp, &a0))
        {
            sipCpp->setAutoScaleY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_setAutoScaleY, doc_QHeightMapSurfaceDataProxy_setAutoScaleY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy_autoScaleY, "autoScaleY(self) -> bool");

extern "C" {static PyObject *meth_QHeightMapSurfaceDataProxy_autoScaleY(PyObject *, PyObject *);}
static PyObject *meth_QHeightMapSurfaceDataProxy_autoScaleY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHeightMapSurfaceDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QHeightMapSurfaceDataProxy, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoScaleY();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QHeightMapSurfaceDataProxy, sipName_autoScaleY, doc_QHeightMapSurfaceDataProxy_autoScaleY);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QHeightMapSurfaceDataProxy(void *, const sipTypeDef *);}
static void *cast_QHeightMapSurfaceDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QHeightMapSurfaceDataProxy *sipCpp = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(sipCppV);

    if (targetType == sipType_QHeightMapSurfaceDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QSurfaceDataProxy)->ctd_cast(static_cast< ::QSurfaceDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QHeightMapSurfaceDataProxy(void *, int);}
static void release_QHeightMapSurfaceDataProxy(void *sipCppV, int)
{
    ::QHeightMapSurfaceDataProxy *sipCpp = reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QHeightMapSurfaceDataProxy(Py_ssize_t);}
static void *array_QHeightMapSurfaceDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QHeightMapSurfaceDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QHeightMapSurfaceDataProxy(void *);}
static void array_delete_QHeightMapSurfaceDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QHeightMapSurfaceDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QHeightMapSurfaceDataProxy(sipSimpleWrapper *);}
static void dealloc_QHeightMapSurfaceDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQHeightMapSurfaceDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QHeightMapSurfaceDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QHeightMapSurfaceDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QHeightMapSurfaceDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQHeightMapSurfaceDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQHeightMapSurfaceDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QImage* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J9|JH", sipType_QImage, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQHeightMapSurfaceDataProxy(*a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1|JH", sipType_QString, &a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQHeightMapSurfaceDataProxy(*a0, a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QHeightMapSurfaceDataProxy[] = {{67, 255, 1}};


static PyMethodDef methods_QHeightMapSurfaceDataProxy[] = {
    {sipName_autoScaleY, meth_QHeightMapSurfaceDataProxy_autoScaleY, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_autoScaleY},
    {sipName_heightMap, meth_QHeightMapSurfaceDataProxy_heightMap, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_heightMap},
    {sipName_heightMapFile, meth_QHeightMapSurfaceDataProxy_heightMapFile, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_heightMapFile},
    {sipName_maxXValue, meth_QHeightMapSurfaceDataProxy_maxXValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_maxXValue},
    {sipName_maxYValue, meth_QHeightMapSurfaceDataProxy_maxYValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_maxYValue},
    {sipName_maxZValue, meth_QHeightMapSurfaceDataProxy_maxZValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_maxZValue},
    {sipName_minXValue, meth_QHeightMapSurfaceDataProxy_minXValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_minXValue},
    {sipName_minYValue, meth_QHeightMapSurfaceDataProxy_minYValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_minYValue},
    {sipName_minZValue, meth_QHeightMapSurfaceDataProxy_minZValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_minZValue},
    {sipName_setAutoScaleY, meth_QHeightMapSurfaceDataProxy_setAutoScaleY, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setAutoScaleY},
    {sipName_setHeightMap, meth_QHeightMapSurfaceDataProxy_setHeightMap, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setHeightMap},
    {sipName_setHeightMapFile, meth_QHeightMapSurfaceDataProxy_setHeightMapFile, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setHeightMapFile},
    {sipName_setMaxXValue, meth_QHeightMapSurfaceDataProxy_setMaxXValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMaxXValue},
    {sipName_setMaxYValue, meth_QHeightMapSurfaceDataProxy_setMaxYValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMaxYValue},
    {sipName_setMaxZValue, meth_QHeightMapSurfaceDataProxy_setMaxZValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMaxZValue},
    {sipName_setMinXValue, meth_QHeightMapSurfaceDataProxy_setMinXValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMinXValue},
    {sipName_setMinYValue, meth_QHeightMapSurfaceDataProxy_setMinYValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMinYValue},
    {sipName_setMinZValue, meth_QHeightMapSurfaceDataProxy_setMinZValue, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setMinZValue},
    {sipName_setValueRanges, meth_QHeightMapSurfaceDataProxy_setValueRanges, METH_VARARGS, doc_QHeightMapSurfaceDataProxy_setValueRanges}
};

PyDoc_STRVAR(doc_QHeightMapSurfaceDataProxy, "\1QHeightMapSurfaceDataProxy(parent: QObject|None = None)\n"
"QHeightMapSurfaceDataProxy(image: QImage, parent: QObject|None = None)\n"
"QHeightMapSurfaceDataProxy(filename: str|None, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QHeightMapSurfaceDataProxy[] = {
    {"autoScaleYChanged(bool)", "\1autoScaleYChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxYValueChanged(float)", "\1maxYValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minYValueChanged(float)", "\1minYValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxZValueChanged(float)", "\1maxZValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minZValueChanged(float)", "\1minZValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxXValueChanged(float)", "\1maxXValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minXValueChanged(float)", "\1minXValueChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"heightMapFileChanged(QString)", "\1heightMapFileChanged(self, filename: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"heightMapChanged(QImage)", "\1heightMapChanged(self, image: QImage)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QHeightMapSurfaceDataProxy = {
    &::QHeightMapSurfaceDataProxy::staticMetaObject,
    signals_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QHeightMapSurfaceDataProxy = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QHeightMapSurfaceDataProxy,
        SIP_NULLPTR,
        &plugin_QHeightMapSurfaceDataProxy,
    },
    {
        sipNameNr_QHeightMapSurfaceDataProxy,
        {0, 0, 1},
        19, methods_QHeightMapSurfaceDataProxy,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QHeightMapSurfaceDataProxy,
    -1,
    -1,
    supers_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR,
    init_type_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR,
    array_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR,
    release_QHeightMapSurfaceDataProxy,
    cast_QHeightMapSurfaceDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QHeightMapSurfaceDataProxy,
    sizeof (::QHeightMapSurfaceDataProxy),
};
