/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 788 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 754 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 848 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 68 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 85 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQAbstract3DInputHandler.cpp"


class sipQAbstract3DInputHandler : public ::QAbstract3DInputHandler
{
public:
    sipQAbstract3DInputHandler(::QObject*);
    virtual ~sipQAbstract3DInputHandler();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstract3DInputHandler(const sipQAbstract3DInputHandler &);
    sipQAbstract3DInputHandler &operator = (const sipQAbstract3DInputHandler &);

    char sipPyMethods[13];
};

sipQAbstract3DInputHandler::sipQAbstract3DInputHandler(::QObject*a0): ::QAbstract3DInputHandler(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstract3DInputHandler::~sipQAbstract3DInputHandler()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstract3DInputHandler::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QAbstract3DInputHandler);

    return ::QAbstract3DInputHandler::metaObject();
}

int sipQAbstract3DInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAbstract3DInputHandler::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QAbstract3DInputHandler, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstract3DInputHandler::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QAbstract3DInputHandler, _clname, &sipCpp) ? sipCpp : ::QAbstract3DInputHandler::qt_metacast(_clname));
}

void sipQAbstract3DInputHandler::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtDataVisualization_5(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::mouseMoveEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::mouseMoveEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_26(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstract3DInputHandler::mouseReleaseEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::mouseReleaseEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_26(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstract3DInputHandler::mousePressEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::mousePressEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_26(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstract3DInputHandler::touchEvent(::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_touchEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::touchEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTouchEvent*);

    sipVH_QtDataVisualization_4(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_6(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstract3DInputHandler::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAbstract3DInputHandler::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstract3DInputHandler::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAbstract3DInputHandler::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstract3DInputHandler::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstract3DInputHandler::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAbstract3DInputHandler::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_mouseDoubleClickEvent, "mouseDoubleClickEvent(self, event: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_mouseDoubleClickEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_mouseDoubleClickEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::mouseDoubleClickEvent(a0) : sipCpp->mouseDoubleClickEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_mouseDoubleClickEvent, doc_QAbstract3DInputHandler_mouseDoubleClickEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_touchEvent, "touchEvent(self, event: QTouchEvent|None)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_touchEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_touchEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTouchEvent* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QTouchEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::touchEvent(a0) : sipCpp->touchEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_touchEvent, doc_QAbstract3DInputHandler_touchEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_mousePressEvent, "mousePressEvent(self, event: QMouseEvent|None, mousePos: QPoint)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        const ::QPoint* a1;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QMouseEvent, &a0, sipType_QPoint, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::mousePressEvent(a0, *a1) : sipCpp->mousePressEvent(a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_mousePressEvent, doc_QAbstract3DInputHandler_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_mouseReleaseEvent, "mouseReleaseEvent(self, event: QMouseEvent|None, mousePos: QPoint)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        const ::QPoint* a1;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QMouseEvent, &a0, sipType_QPoint, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::mouseReleaseEvent(a0, *a1) : sipCpp->mouseReleaseEvent(a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_mouseReleaseEvent, doc_QAbstract3DInputHandler_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_mouseMoveEvent, "mouseMoveEvent(self, event: QMouseEvent|None, mousePos: QPoint)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        const ::QPoint* a1;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QMouseEvent, &a0, sipType_QPoint, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::mouseMoveEvent(a0, *a1) : sipCpp->mouseMoveEvent(a0, *a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_mouseMoveEvent, doc_QAbstract3DInputHandler_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_wheelEvent, "wheelEvent(self, event: QWheelEvent|None)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstract3DInputHandler)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstract3DInputHandler::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_wheelEvent, doc_QAbstract3DInputHandler_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_inputView, "inputView(self) -> QAbstract3DInputHandler.InputView");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_inputView(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_inputView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp))
        {
            ::QAbstract3DInputHandler::InputView sipRes;

            sipRes = sipCpp->inputView();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstract3DInputHandler_InputView);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_inputView, doc_QAbstract3DInputHandler_inputView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_setInputView, "setInputView(self, inputView: QAbstract3DInputHandler.InputView)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_setInputView(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_setInputView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstract3DInputHandler::InputView a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QAbstract3DInputHandler_InputView, &a0))
        {
            sipCpp->setInputView(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_setInputView, doc_QAbstract3DInputHandler_setInputView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_inputPosition, "inputPosition(self) -> QPoint");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_inputPosition(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_inputPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->inputPosition());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_inputPosition, doc_QAbstract3DInputHandler_inputPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_setInputPosition, "setInputPosition(self, position: QPoint)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_setInputPosition(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_setInputPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setInputPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_setInputPosition, doc_QAbstract3DInputHandler_setInputPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_scene, "scene(self) -> Q3DScene|None");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_scene(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_scene(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp))
        {
            ::Q3DScene*sipRes;

            sipRes = sipCpp->scene();

            return sipConvertFromType(sipRes, sipType_Q3DScene, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_scene, doc_QAbstract3DInputHandler_scene);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_setScene, "setScene(self, scene: Q3DScene|None)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_setScene(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_setScene(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Q3DScene* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_Q3DScene, &a0))
        {
            sipCpp->setScene(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_setScene, doc_QAbstract3DInputHandler_setScene);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_setPrevDistance, "setPrevDistance(self, distance: int)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_setPrevDistance(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_setPrevDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pi", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, &a0))
        {
            sipCpp->setPrevDistance(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_setPrevDistance, doc_QAbstract3DInputHandler_setPrevDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_prevDistance, "prevDistance(self) -> int");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_prevDistance(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_prevDistance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->prevDistance();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_prevDistance, doc_QAbstract3DInputHandler_prevDistance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_setPreviousInputPos, "setPreviousInputPos(self, position: QPoint)");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_setPreviousInputPos(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_setPreviousInputPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setPreviousInputPos(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_setPreviousInputPos, doc_QAbstract3DInputHandler_setPreviousInputPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstract3DInputHandler_previousInputPos, "previousInputPos(self) -> QPoint");

extern "C" {static PyObject *meth_QAbstract3DInputHandler_previousInputPos(PyObject *, PyObject *);}
static PyObject *meth_QAbstract3DInputHandler_previousInputPos(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstract3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstract3DInputHandler, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->previousInputPos());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DInputHandler, sipName_previousInputPos, doc_QAbstract3DInputHandler_previousInputPos);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstract3DInputHandler(void *, const sipTypeDef *);}
static void *cast_QAbstract3DInputHandler(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstract3DInputHandler *sipCpp = reinterpret_cast< ::QAbstract3DInputHandler *>(sipCppV);

    if (targetType == sipType_QAbstract3DInputHandler)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstract3DInputHandler(void *, int);}
static void release_QAbstract3DInputHandler(void *sipCppV, int)
{
    ::QAbstract3DInputHandler *sipCpp = reinterpret_cast< ::QAbstract3DInputHandler *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAbstract3DInputHandler(Py_ssize_t);}
static void *array_QAbstract3DInputHandler(Py_ssize_t sipNrElem)
{
    return new ::QAbstract3DInputHandler[sipNrElem];
}


extern "C" {static void array_delete_QAbstract3DInputHandler(void *);}
static void array_delete_QAbstract3DInputHandler(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAbstract3DInputHandler *>(sipCpp);
}


extern "C" {static void dealloc_QAbstract3DInputHandler(sipSimpleWrapper *);}
static void dealloc_QAbstract3DInputHandler(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstract3DInputHandler *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstract3DInputHandler(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstract3DInputHandler(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstract3DInputHandler(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstract3DInputHandler *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQAbstract3DInputHandler(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstract3DInputHandler[] = {{8, 0, 1}};


static PyMethodDef methods_QAbstract3DInputHandler[] = {
    {sipName_inputPosition, meth_QAbstract3DInputHandler_inputPosition, METH_VARARGS, doc_QAbstract3DInputHandler_inputPosition},
    {sipName_inputView, meth_QAbstract3DInputHandler_inputView, METH_VARARGS, doc_QAbstract3DInputHandler_inputView},
    {sipName_mouseDoubleClickEvent, meth_QAbstract3DInputHandler_mouseDoubleClickEvent, METH_VARARGS, doc_QAbstract3DInputHandler_mouseDoubleClickEvent},
    {sipName_mouseMoveEvent, meth_QAbstract3DInputHandler_mouseMoveEvent, METH_VARARGS, doc_QAbstract3DInputHandler_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QAbstract3DInputHandler_mousePressEvent, METH_VARARGS, doc_QAbstract3DInputHandler_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QAbstract3DInputHandler_mouseReleaseEvent, METH_VARARGS, doc_QAbstract3DInputHandler_mouseReleaseEvent},
    {sipName_prevDistance, meth_QAbstract3DInputHandler_prevDistance, METH_VARARGS, doc_QAbstract3DInputHandler_prevDistance},
    {sipName_previousInputPos, meth_QAbstract3DInputHandler_previousInputPos, METH_VARARGS, doc_QAbstract3DInputHandler_previousInputPos},
    {sipName_scene, meth_QAbstract3DInputHandler_scene, METH_VARARGS, doc_QAbstract3DInputHandler_scene},
    {sipName_setInputPosition, meth_QAbstract3DInputHandler_setInputPosition, METH_VARARGS, doc_QAbstract3DInputHandler_setInputPosition},
    {sipName_setInputView, meth_QAbstract3DInputHandler_setInputView, METH_VARARGS, doc_QAbstract3DInputHandler_setInputView},
    {sipName_setPrevDistance, meth_QAbstract3DInputHandler_setPrevDistance, METH_VARARGS, doc_QAbstract3DInputHandler_setPrevDistance},
    {sipName_setPreviousInputPos, meth_QAbstract3DInputHandler_setPreviousInputPos, METH_VARARGS, doc_QAbstract3DInputHandler_setPreviousInputPos},
    {sipName_setScene, meth_QAbstract3DInputHandler_setScene, METH_VARARGS, doc_QAbstract3DInputHandler_setScene},
    {sipName_touchEvent, meth_QAbstract3DInputHandler_touchEvent, METH_VARARGS, doc_QAbstract3DInputHandler_touchEvent},
    {sipName_wheelEvent, meth_QAbstract3DInputHandler_wheelEvent, METH_VARARGS, doc_QAbstract3DInputHandler_wheelEvent}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAbstract3DInputHandler[] = {
    {sipName_InputViewNone, static_cast<int>(::QAbstract3DInputHandler::InputViewNone)},
    {sipName_InputViewOnPrimary, static_cast<int>(::QAbstract3DInputHandler::InputViewOnPrimary)},
    {sipName_InputViewOnSecondary, static_cast<int>(::QAbstract3DInputHandler::InputViewOnSecondary)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAbstract3DInputHandler, "\1QAbstract3DInputHandler(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAbstract3DInputHandler[] = {
    {"sceneChanged(Q3DScene*)", "\1sceneChanged(self, scene: Q3DScene|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"inputViewChanged(QAbstract3DInputHandler::InputView)", "\1inputViewChanged(self, view: QAbstract3DInputHandler.InputView)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(QPoint)", "\1positionChanged(self, position: QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAbstract3DInputHandler = {
    &::QAbstract3DInputHandler::staticMetaObject,
    signals_QAbstract3DInputHandler,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QAbstract3DInputHandler = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstract3DInputHandler,
        SIP_NULLPTR,
        &plugin_QAbstract3DInputHandler,
    },
    {
        sipNameNr_QAbstract3DInputHandler,
        {0, 0, 1},
        16, methods_QAbstract3DInputHandler,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAbstract3DInputHandler, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstract3DInputHandler,
    -1,
    -1,
    supers_QAbstract3DInputHandler,
    SIP_NULLPTR,
    init_type_QAbstract3DInputHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstract3DInputHandler,
    SIP_NULLPTR,
    array_QAbstract3DInputHandler,
    SIP_NULLPTR,
    release_QAbstract3DInputHandler,
    cast_QAbstract3DInputHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAbstract3DInputHandler,
    sizeof (::QAbstract3DInputHandler),
};
