/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataItem.cpp"

#line 81 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurfaceDataItem.cpp"


PyDoc_STRVAR(doc_QSurfaceDataItem_setPosition, "setPosition(self, position: QVector3D)");

extern "C" {static PyObject *meth_QSurfaceDataItem_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSurfaceDataItem, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_setPosition, doc_QSurfaceDataItem_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QSurfaceDataItem_position(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataItem, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_position, doc_QSurfaceDataItem_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_setX, "setX(self, value: float)");

extern "C" {static PyObject *meth_QSurfaceDataItem_setX(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_setX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSurfaceDataItem, &sipCpp, &a0))
        {
            sipCpp->setX(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_setX, doc_QSurfaceDataItem_setX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_setY, "setY(self, value: float)");

extern "C" {static PyObject *meth_QSurfaceDataItem_setY(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_setY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSurfaceDataItem, &sipCpp, &a0))
        {
            sipCpp->setY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_setY, doc_QSurfaceDataItem_setY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_setZ, "setZ(self, value: float)");

extern "C" {static PyObject *meth_QSurfaceDataItem_setZ(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_setZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QSurfaceDataItem, &sipCpp, &a0))
        {
            sipCpp->setZ(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_setZ, doc_QSurfaceDataItem_setZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_x, "x(self) -> float");

extern "C" {static PyObject *meth_QSurfaceDataItem_x(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_x(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->x();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_x, doc_QSurfaceDataItem_x);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_y, "y(self) -> float");

extern "C" {static PyObject *meth_QSurfaceDataItem_y(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_y(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->y();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_y, doc_QSurfaceDataItem_y);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurfaceDataItem_z, "z(self) -> float");

extern "C" {static PyObject *meth_QSurfaceDataItem_z(PyObject *, PyObject *);}
static PyObject *meth_QSurfaceDataItem_z(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurfaceDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurfaceDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->z();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurfaceDataItem, sipName_z, doc_QSurfaceDataItem_z);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSurfaceDataItem(void *, int);}
static void release_QSurfaceDataItem(void *sipCppV, int)
{
    delete reinterpret_cast< ::QSurfaceDataItem *>(sipCppV);
}


extern "C" {static void *array_QSurfaceDataItem(Py_ssize_t);}
static void *array_QSurfaceDataItem(Py_ssize_t sipNrElem)
{
    return new ::QSurfaceDataItem[sipNrElem];
}


extern "C" {static void array_delete_QSurfaceDataItem(void *);}
static void array_delete_QSurfaceDataItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSurfaceDataItem *>(sipCpp);
}


extern "C" {static void assign_QSurfaceDataItem(void *, Py_ssize_t, void *);}
static void assign_QSurfaceDataItem(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QSurfaceDataItem *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QSurfaceDataItem *>(sipSrc);
}


extern "C" {static void *copy_QSurfaceDataItem(const void *, Py_ssize_t);}
static void *copy_QSurfaceDataItem(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QSurfaceDataItem(reinterpret_cast<const ::QSurfaceDataItem *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QSurfaceDataItem(sipSimpleWrapper *);}
static void dealloc_QSurfaceDataItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSurfaceDataItem(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QSurfaceDataItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSurfaceDataItem(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QSurfaceDataItem *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QSurfaceDataItem();

            return sipCpp;
        }
    }

    {
        const ::QVector3D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector3D, &a0))
        {
            sipCpp = new ::QSurfaceDataItem(*a0);

            return sipCpp;
        }
    }

    {
        const ::QSurfaceDataItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QSurfaceDataItem, &a0))
        {
            sipCpp = new ::QSurfaceDataItem(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QSurfaceDataItem[] = {
    {sipName_position, meth_QSurfaceDataItem_position, METH_VARARGS, doc_QSurfaceDataItem_position},
    {sipName_setPosition, meth_QSurfaceDataItem_setPosition, METH_VARARGS, doc_QSurfaceDataItem_setPosition},
    {sipName_setX, meth_QSurfaceDataItem_setX, METH_VARARGS, doc_QSurfaceDataItem_setX},
    {sipName_setY, meth_QSurfaceDataItem_setY, METH_VARARGS, doc_QSurfaceDataItem_setY},
    {sipName_setZ, meth_QSurfaceDataItem_setZ, METH_VARARGS, doc_QSurfaceDataItem_setZ},
    {sipName_x, meth_QSurfaceDataItem_x, METH_VARARGS, doc_QSurfaceDataItem_x},
    {sipName_y, meth_QSurfaceDataItem_y, METH_VARARGS, doc_QSurfaceDataItem_y},
    {sipName_z, meth_QSurfaceDataItem_z, METH_VARARGS, doc_QSurfaceDataItem_z}
};

PyDoc_STRVAR(doc_QSurfaceDataItem, "\1QSurfaceDataItem()\n"
"QSurfaceDataItem(position: QVector3D)\n"
"QSurfaceDataItem(other: QSurfaceDataItem)");


sipClassTypeDef sipTypeDef_QtDataVisualization_QSurfaceDataItem = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSurfaceDataItem,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QSurfaceDataItem,
        {0, 0, 1},
        8, methods_QSurfaceDataItem,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSurfaceDataItem,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QSurfaceDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSurfaceDataItem,
    assign_QSurfaceDataItem,
    array_QSurfaceDataItem,
    copy_QSurfaceDataItem,
    release_QSurfaceDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSurfaceDataItem,
    sizeof (::QSurfaceDataItem),
};
