/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qvalue3daxisformatter.sip"
#include <qvalue3daxisformatter.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 1197 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 56 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 59 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 85 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 88 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 91 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 94 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 97 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQLogValue3DAxisFormatter.cpp"


class sipQLogValue3DAxisFormatter : public ::QLogValue3DAxisFormatter
{
public:
    sipQLogValue3DAxisFormatter(::QObject*);
    virtual ~sipQLogValue3DAxisFormatter();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    ::QValue3DAxisFormatter* createNewInstance() const SIP_OVERRIDE;
    void recalculate() SIP_OVERRIDE;
    ::QString stringForValue(::qreal, const ::QString&) const SIP_OVERRIDE;
    float positionAt(float) const SIP_OVERRIDE;
    float valueAt(float) const SIP_OVERRIDE;
    void populateCopy(::QValue3DAxisFormatter&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQLogValue3DAxisFormatter(const sipQLogValue3DAxisFormatter &);
    sipQLogValue3DAxisFormatter &operator = (const sipQLogValue3DAxisFormatter &);

    char sipPyMethods[13];
};

sipQLogValue3DAxisFormatter::sipQLogValue3DAxisFormatter(::QObject*a0): ::QLogValue3DAxisFormatter(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQLogValue3DAxisFormatter::~sipQLogValue3DAxisFormatter()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQLogValue3DAxisFormatter::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QLogValue3DAxisFormatter);

    return ::QLogValue3DAxisFormatter::metaObject();
}

int sipQLogValue3DAxisFormatter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QLogValue3DAxisFormatter::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QLogValue3DAxisFormatter, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQLogValue3DAxisFormatter::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QLogValue3DAxisFormatter, _clname, &sipCpp) ? sipCpp : ::QLogValue3DAxisFormatter::qt_metacast(_clname));
}

void sipQLogValue3DAxisFormatter::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLogValue3DAxisFormatter::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLogValue3DAxisFormatter::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLogValue3DAxisFormatter::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLogValue3DAxisFormatter::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQLogValue3DAxisFormatter::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQLogValue3DAxisFormatter::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QValue3DAxisFormatter* sipQLogValue3DAxisFormatter::createNewInstance() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[7]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_createNewInstance);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::createNewInstance();

    extern ::QValue3DAxisFormatter* sipVH_QtDataVisualization_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_27(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQLogValue3DAxisFormatter::recalculate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_recalculate);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::recalculate();
        return;
    }

    extern void sipVH_QtDataVisualization_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtDataVisualization_28(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQLogValue3DAxisFormatter::stringForValue(::qreal a0, const ::QString& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_stringForValue);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::stringForValue(a0, a1);

    extern ::QString sipVH_QtDataVisualization_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal, const ::QString&);

    return sipVH_QtDataVisualization_29(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

float sipQLogValue3DAxisFormatter::positionAt(float a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_positionAt);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::positionAt(a0);

    extern float sipVH_QtDataVisualization_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, float);

    return sipVH_QtDataVisualization_30(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

float sipQLogValue3DAxisFormatter::valueAt(float a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_valueAt);

    if (!sipMeth)
        return ::QLogValue3DAxisFormatter::valueAt(a0);

    extern float sipVH_QtDataVisualization_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, float);

    return sipVH_QtDataVisualization_30(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQLogValue3DAxisFormatter::populateCopy(::QValue3DAxisFormatter& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_populateCopy);

    if (!sipMeth)
    {
        ::QLogValue3DAxisFormatter::populateCopy(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QValue3DAxisFormatter&);

    sipVH_QtDataVisualization_31(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_setBase, "setBase(self, base: float)");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_setBase(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_setBase(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qreal a0;
        ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->setBase(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_setBase, doc_QLogValue3DAxisFormatter_setBase);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_base, "base(self) -> float");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_base(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_base(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp))
        {
            ::qreal sipRes;

            sipRes = sipCpp->base();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_base, doc_QLogValue3DAxisFormatter_base);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_setAutoSubGrid, "setAutoSubGrid(self, enabled: bool)");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_setAutoSubGrid(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_setAutoSubGrid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->setAutoSubGrid(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_setAutoSubGrid, doc_QLogValue3DAxisFormatter_setAutoSubGrid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_autoSubGrid, "autoSubGrid(self) -> bool");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_autoSubGrid(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_autoSubGrid(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->autoSubGrid();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_autoSubGrid, doc_QLogValue3DAxisFormatter_autoSubGrid);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_setShowEdgeLabels, "setShowEdgeLabels(self, enabled: bool)");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_setShowEdgeLabels(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_setShowEdgeLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->setShowEdgeLabels(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_setShowEdgeLabels, doc_QLogValue3DAxisFormatter_setShowEdgeLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_showEdgeLabels, "showEdgeLabels(self) -> bool");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_showEdgeLabels(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_showEdgeLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showEdgeLabels();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_showEdgeLabels, doc_QLogValue3DAxisFormatter_showEdgeLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_createNewInstance, "createNewInstance(self) -> QValue3DAxisFormatter|None");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_createNewInstance(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_createNewInstance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLogValue3DAxisFormatter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp))
        {
            ::QValue3DAxisFormatter*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLogValue3DAxisFormatter::createNewInstance() : sipCpp->createNewInstance());

            return sipConvertFromType(sipRes, sipType_QValue3DAxisFormatter, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_createNewInstance, doc_QLogValue3DAxisFormatter_createNewInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_recalculate, "recalculate(self)");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_recalculate(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_recalculate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLogValue3DAxisFormatter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QLogValue3DAxisFormatter::recalculate() : sipCpp->recalculate());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_recalculate, doc_QLogValue3DAxisFormatter_recalculate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_positionAt, "positionAt(self, value: float) -> float");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_positionAt(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_positionAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLogValue3DAxisFormatter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        float a0;
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pf", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, &a0))
        {
            float sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLogValue3DAxisFormatter::positionAt(a0) : sipCpp->positionAt(a0));

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_positionAt, doc_QLogValue3DAxisFormatter_positionAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_valueAt, "valueAt(self, position: float) -> float");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_valueAt(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_valueAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLogValue3DAxisFormatter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        float a0;
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pf", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, &a0))
        {
            float sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QLogValue3DAxisFormatter::valueAt(a0) : sipCpp->valueAt(a0));

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_valueAt, doc_QLogValue3DAxisFormatter_valueAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLogValue3DAxisFormatter_populateCopy, "populateCopy(self, copy: QValue3DAxisFormatter)");

extern "C" {static PyObject *meth_QLogValue3DAxisFormatter_populateCopy(PyObject *, PyObject *);}
static PyObject *meth_QLogValue3DAxisFormatter_populateCopy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QLogValue3DAxisFormatter)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QValue3DAxisFormatter* a0;
        const ::QLogValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QLogValue3DAxisFormatter, &sipCpp, sipType_QValue3DAxisFormatter, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QLogValue3DAxisFormatter::populateCopy(*a0) : sipCpp->populateCopy(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLogValue3DAxisFormatter, sipName_populateCopy, doc_QLogValue3DAxisFormatter_populateCopy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QLogValue3DAxisFormatter(void *, const sipTypeDef *);}
static void *cast_QLogValue3DAxisFormatter(void *sipCppV, const sipTypeDef *targetType)
{
    ::QLogValue3DAxisFormatter *sipCpp = reinterpret_cast< ::QLogValue3DAxisFormatter *>(sipCppV);

    if (targetType == sipType_QLogValue3DAxisFormatter)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QValue3DAxisFormatter)->ctd_cast(static_cast< ::QValue3DAxisFormatter *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLogValue3DAxisFormatter(void *, int);}
static void release_QLogValue3DAxisFormatter(void *sipCppV, int)
{
    ::QLogValue3DAxisFormatter *sipCpp = reinterpret_cast< ::QLogValue3DAxisFormatter *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QLogValue3DAxisFormatter(Py_ssize_t);}
static void *array_QLogValue3DAxisFormatter(Py_ssize_t sipNrElem)
{
    return new ::QLogValue3DAxisFormatter[sipNrElem];
}


extern "C" {static void array_delete_QLogValue3DAxisFormatter(void *);}
static void array_delete_QLogValue3DAxisFormatter(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLogValue3DAxisFormatter *>(sipCpp);
}


extern "C" {static void dealloc_QLogValue3DAxisFormatter(sipSimpleWrapper *);}
static void dealloc_QLogValue3DAxisFormatter(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQLogValue3DAxisFormatter *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLogValue3DAxisFormatter(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QLogValue3DAxisFormatter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLogValue3DAxisFormatter(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQLogValue3DAxisFormatter *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQLogValue3DAxisFormatter(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QLogValue3DAxisFormatter[] = {{70, 255, 1}};


static PyMethodDef methods_QLogValue3DAxisFormatter[] = {
    {sipName_autoSubGrid, meth_QLogValue3DAxisFormatter_autoSubGrid, METH_VARARGS, doc_QLogValue3DAxisFormatter_autoSubGrid},
    {sipName_base, meth_QLogValue3DAxisFormatter_base, METH_VARARGS, doc_QLogValue3DAxisFormatter_base},
    {sipName_createNewInstance, meth_QLogValue3DAxisFormatter_createNewInstance, METH_VARARGS, doc_QLogValue3DAxisFormatter_createNewInstance},
    {sipName_populateCopy, meth_QLogValue3DAxisFormatter_populateCopy, METH_VARARGS, doc_QLogValue3DAxisFormatter_populateCopy},
    {sipName_positionAt, meth_QLogValue3DAxisFormatter_positionAt, METH_VARARGS, doc_QLogValue3DAxisFormatter_positionAt},
    {sipName_recalculate, meth_QLogValue3DAxisFormatter_recalculate, METH_VARARGS, doc_QLogValue3DAxisFormatter_recalculate},
    {sipName_setAutoSubGrid, meth_QLogValue3DAxisFormatter_setAutoSubGrid, METH_VARARGS, doc_QLogValue3DAxisFormatter_setAutoSubGrid},
    {sipName_setBase, meth_QLogValue3DAxisFormatter_setBase, METH_VARARGS, doc_QLogValue3DAxisFormatter_setBase},
    {sipName_setShowEdgeLabels, meth_QLogValue3DAxisFormatter_setShowEdgeLabels, METH_VARARGS, doc_QLogValue3DAxisFormatter_setShowEdgeLabels},
    {sipName_showEdgeLabels, meth_QLogValue3DAxisFormatter_showEdgeLabels, METH_VARARGS, doc_QLogValue3DAxisFormatter_showEdgeLabels},
    {sipName_valueAt, meth_QLogValue3DAxisFormatter_valueAt, METH_VARARGS, doc_QLogValue3DAxisFormatter_valueAt}
};

PyDoc_STRVAR(doc_QLogValue3DAxisFormatter, "\1QLogValue3DAxisFormatter(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QLogValue3DAxisFormatter[] = {
    {"showEdgeLabelsChanged(bool)", "\1showEdgeLabelsChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoSubGridChanged(bool)", "\1autoSubGridChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"baseChanged(qreal)", "\1baseChanged(self, base: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QLogValue3DAxisFormatter = {
    &::QLogValue3DAxisFormatter::staticMetaObject,
    signals_QLogValue3DAxisFormatter,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QLogValue3DAxisFormatter = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLogValue3DAxisFormatter,
        SIP_NULLPTR,
        &plugin_QLogValue3DAxisFormatter,
    },
    {
        sipNameNr_QLogValue3DAxisFormatter,
        {0, 0, 1},
        11, methods_QLogValue3DAxisFormatter,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLogValue3DAxisFormatter,
    -1,
    -1,
    supers_QLogValue3DAxisFormatter,
    SIP_NULLPTR,
    init_type_QLogValue3DAxisFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLogValue3DAxisFormatter,
    SIP_NULLPTR,
    array_QLogValue3DAxisFormatter,
    SIP_NULLPTR,
    release_QLogValue3DAxisFormatter,
    cast_QLogValue3DAxisFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLogValue3DAxisFormatter,
    sizeof (::QLogValue3DAxisFormatter),
};
